from django.core.management.base import BaseCommand

from denorm.tasks import flush_via_queue


class Command(BaseCommand):
    help = (
        "Recalculates the value of every denormalized field that was marked dirty using "
        "Celery queues."
    )

    def handle(self, **kwargs):
        flush_via_queue.apply_async()



from celery import shared_task

from denorm import denorms


@shared_task(ignore_result=True)
def flush_single(pk: int):
    denorms.flush_single(pk)


@shared_task(ignore_result=True)
def flush_via_queue():
    from denorm.models import DirtyInstance

    for elem in DirtyInstance.objects.all():
        flush_single.delay(pk=elem.pk)



# Generated by Django 4.2.3 on 2023-07-09 20:24

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0006_alter_forum_author_names"),
    ]

    operations = [
        migrations.AlterField(
            model_name="post",
            name="response_count",
            field=models.PositiveIntegerField(default=0, editable=False),
        ),
    ]
